__code__='GatU0D/[on&>$QoP(Q(>!\\J?8(.`Qj\\:^SG<J;"O&L`f`7!CoMUQsqc2Mm::2S4=X71,YPiX>dC^W+LOL\'4:rdC\\6)H?WtmB4a:?6LgPCH\'bCR7fk?\\O<ffYJ-\'$Z]E7kT-pS)Fd:2YN<!A@Q\'sImE#AaA]!Ls4]#&F>^"[!"a%H)6A\'7_lhhZD()SckPc49]sJn2nGS!RCb;"[!$7*q06h%tO8)EoMA0Z0qR;*r`.SYQi!+W!5%S2,JF?<<_pP/Z_+9_)"EEb]65WIY:#Q1<!W)M7\'RHY<qgkNc0r2E\\UC$\']Nm/_^b9`/_13.,\\k<bZMFYuLOadRVdEK@!pnC7Z?IL#\\mR&M:=W4qY<[9/e0Cds4SU^P\\]bY3jsWfN_>()0LV:aOpK@u:O-&!n2R$6:3j%iUYu,Dj\'YCI?=H?Ib?ZRUbL5Rgl9RC;./L.>E/IpD>F+o:-e\\pb2qGM[>]suQH3p[PbS["/`di#?e0t+DOB:`]$bY5:PBSoqI,C2?sDu"hpN0NecVL\'2W30*g"\'maSgqU6b_f95?a[q/YuKT#6l_8*/!;ta4WC?l&hEn,LlOHGZVN2\'2q7\\S$_d0ZpK2\\,%g=e#B@l0Rj+[^FkKKCsDTNnQ8_h"+4/T$\'2]4:Z1l-8O+L9sR<Ra"Yd3%_H4Q19KZ8T&BseWRg+RQ:/H#eMZoJeX*XEbU$G?\')7L8L:Q"pQ!+d$rEukhR>Zh&.M+cGaQ$VbMiLM@"3TFiV:K9.]0^Hl)s_Gn0WL\\5YOq1$H7n\'aH%X,=S%nlKC[\'I1k_Y]j`;F%QPtloj-bB4WfDJ$pBZ0\'UJXN$0A25jE=QV6JSseOmh,<3TP\\cX\'cO[^#LKE>!H%ubSa7Hn:?1EES-$CIkJgaZ%3-\\u&#8GVRinJhFr!l[ceredP:STaiM07\'s$a<r\\MeaRb$XE\\W"gtM>nBs/q.]g9-:cm=fNprbLCT\\tfFg&b<m^k,e%&;2GI\\..AL9\'me=-n&^SRsoTlif;M3SI`hU;Y;^:R.KlpObFP!`6<D-KP#$AC\\a\\3nmEtoH!]%s\',.KnCr4M\\\\jHP<EK,H)q/8"2#cNbVD9M;Q1smZIUi~>'



#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.charts.piecharts import LegendedPie
from reportlab.graphics.shapes import _DrawingEditorMixin
from rlextra.graphics.guiedit.datacharts import CSVDataSource, ODBCDataSource, DataAssociation, DataAwareDrawing

class LegendedPieDrawing(_DrawingEditorMixin,DataAwareDrawing):
	def __init__(self,width=400,height=200,*args,**kw):
		DataAwareDrawing.__init__(self,width,height,*args,**kw)
		self._add(self,LegendedPie(),name='chart',validate=None,desc='The main chart')
		self.height = 110
		self.width = 200
		self.dataSource = CSVDataSource()
		self.dataSource.filename = 'legendedpie.csv'
		self.dataSource.sep = '\t'
		self.dataSource.sql = 'SELECT chartID,sliceId,name,value FROM generic_pie'
		self.dataSource.groupingColumn = 'chartId'
		self.dataSource.integerColumns = ['chartId']
		self.dataSource.floatColumns = ['value']
		self.dataSource.associations.size      = 4
		self.dataSource.groupingColumn         = 0
		self.dataSource.associations.element00 = DataAssociation(column=0, target='chartId', assocType='scalar')
		self.dataSource.associations.element01 = DataAssociation(column=3, target='chart.data', assocType='vector')
		self.dataSource.associations.element02 = DataAssociation(column=2, target='chart.legend_names', assocType='vector')
		self.dataSource.associations.element03 = DataAssociation(column=3, target='chart.legend_data', assocType='vector')
		self.fileNamePattern = 'piechart%03d'
		self.formats         = ['eps','pdf']
		self.verbose         = 1
		self.outDir          = './output/'


if __name__=="__main__": #NORUNTESTS
	LegendedPieDrawing().go()



from django.shortcuts import render_to_response
from django.http import HttpResponse
from django.template import Template, Context

from rlextra.rml2pdf import rml2pdf
import io


def search_form(request):
    return render_to_response('search_form.html')


def getPDF(request):
    """Returns PDF as a binary stream."""

    if 'q' in request.GET:
            
        rml = getRML(request.GET['q'])  
    
        buf = io.StringIO()
        
        #create the pdf
        rml2pdf.go(rml, outputFileName=buf)
        buf.reset()
        pdfData = buf.read()
        
        #send the response
        response = HttpResponse(mimetype='application/pdf')
        response.write(pdfData)
        response['Content-Disposition'] = 'attachment; filename=output.pdf'
        return response

def getRML(name):
    """We used django template to write the RML, but you could use any other
    template language of your choice. 
    """
    t = Template(open('hello.rml').read())
    c = Context({"name": name})
    rml = t.render(c)
    #django templates are unicode, and so need to be encoded to utf-8
    return rml.encode('utf8')



#Autogenerated by ReportLab guiedit do not edit
import reportlab
from reportlab.graphics.widgets.grids import ShadedRect
from reportlab.lib.colors import PCMYKColor, white, red
from rlextra.graphics.guiedit.datacharts import DataAwareDrawing, CSVDataSource, ODBCDataSource, Array, DataAssociation
from reportlab.graphics.charts.barcharts import VerticalBarChart
from reportlab.lib.corp import cm
from reportlab.graphics.shapes import _DrawingEditorMixin, String

class CylinderBarStacked(_DrawingEditorMixin,DataAwareDrawing):
	def __init__(self,width=400,height=200,*args,**kw):
		DataAwareDrawing.__init__(self,width,height,*args,**kw)
		self.width           = 8.4*cm
		self.height          = 8.3*cm
		self.outDir          = './output/'
		self.verbose         = 1
		self._add(self,VerticalBarChart(),name='chart',validate=None,desc='Main bar chart')
		self.chart.barLabels.fontName        = 'Helvetica'
		self.chart.barLabels.fontSize        = 7
		self.chart.data           = [(3389, 19444, 8744, 11200), (3389, 19444, 8744, 11200)]
		self.chart.barLabelFormat = '\xc2\xa3%d'
		self.chart.groupSpacing   = 0.55*cm
		self.chart.bars.symbol        = ShadedRect()
		self.chart.bars.symbol.cylinderMode   = 1
		self.chart.bars.symbol.fillColorEnd   = PCMYKColor(0,0,0,0)
		self.chart.bars.symbol.fillColorStart = PCMYKColor(86,0,17,0)
		self.chart.y              = 2.7*cm
		self.chart.x              = 1.5*cm
		self.chart.valueAxis.tickLeft           = 0
		self.chart.categoryAxis.tickDown        = 0
		self.chart.categoryAxis.visibleAxis     = 0
		self.chart.categoryAxis.visibleTicks    = 1
		self.chart.categoryAxis.categoryNames   = ['1 year', '3 year', '5 year', '10 year']
		self.chart.categoryAxis.labels.fontName     = 'Helvetica'
		self.chart.categoryAxis.labels.fontSize     = 7
		self.chart.valueAxis.labels.fontName        = 'Helvetica'
		self.chart.valueAxis.labels.fontSize        = 7
		self.chart.valueAxis.valueMin           = 0
		self.chart.valueAxis.valueMax           = 20000
		self.chart.valueAxis.valueMax           = None
		self.chart.valueAxis.valueMin           = None
		self.chart.valueAxis.visibleAxis        = 0
		self.chart.valueAxis.strokeColor        = None
		self.chart.valueAxis.forceZero          = 1
		self.chart.bars.strokeColor   = None
		self.chart.bars.symbol.strokeColor    = None
		self.chart.barLabels.dy              = 0.2*cm
		self.chart.barWidth       = 0.7*cm
		self.chart.barSpacing     = 0.6*cm
		self._add(self,String(self.width/2.0,1.6*cm,''),name='caption',validate=None,desc='Caption below this table')
		self.caption.fontName   = 'Helvetica'
		self.caption.fontSize   = 7
		self.caption.text       = 'Savings Split'
		self.caption.textAnchor = 'middle'
		self.fileNamePattern = 'stackedbars%03d'
		self.formats         = ['eps','pdf']
		self.chart.bars.symbol.numShades      = 50
		self.chart.height         = 4.5*cm
		self.dataSource      = CSVDataSource()
		self.dataSource.filename = 'stackedBar.csv'
		self.dataSource.groupingColumn = 'chartId'
		self.dataSource.integerColumns = ['chartId','rowId']
		self.dataSource.floatColumns = ['value1','value2','value3']
		self.dataSource.sep = '\t'
		self.dataSource.associations   = Array(3, DataAssociation)
		self.dataSource.sql            = 'SELECT * FROM generic_bar ORDER BY chartId, rowId'
		self.dataSource.associations.element00 = DataAssociation(column=0, target='chartId', assocType='scalar')
		self.dataSource.associations.element01 = DataAssociation(column=[3,4], target='chart.data', assocType='tmatrix')
		self.dataSource.associations.element02 = DataAssociation(column=2, target='chart.categoryAxis.categoryNames', assocType='vector')
		self.skipIfColumnIsNull(3)
		self.skipIfColumnContainsNull(3)
		self.chart.bars.symbol        = None
		self.chart.bars[0].symbol=ShadedRect()
		self.chart.bars[0].symbol.cylinderMode   = 1
		self.chart.bars[0].symbol.fillColorEnd   = PCMYKColor(0,0,0,0)
		self.chart.bars[0].symbol.fillColorStart = PCMYKColor(86,0,17,0)
		self.chart.bars[0].symbol.numShades      = 50
		self.chart.bars[0].symbol.strokeColor    = None
		self.chart.bars[1].symbol=ShadedRect()
		self.chart.bars[1].symbol.cylinderMode   = 1
		self.chart.bars[1].symbol.fillColorEnd   = PCMYKColor(0,0,0,0)
		self.chart.bars[1].symbol.fillColorStart = PCMYKColor(0,100,91,0)
		self.chart.bars[1].symbol.numShades      = 50
		self.chart.bars[1].symbol.strokeColor    = None
		self.chart.categoryAxis.style='stacked'
		self.chart.barLabels.dy              = -5.66929133858
		self.chart.categoryAxis.labels.maxWidth       = 40
		self.chart.categoryAxis.labels.width          = None
		self.chart.categoryAxis.labels.maxWidth       = 25
		self.chart.categoryAxis.labels.fontSize       = 6
		self.chart.categoryAxis.labels.textAnchor     = 'middle'

if __name__=="__main__": #NORUNTESTS
	CylinderBarStacked().go()



# vim: sw=4:expandtab:foldmethod=marker
#
# Copyright (c) 2006, Mathieu Fenniak
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# * Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# * Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# * The name of the author may not be used to endorse or promote products
# derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.


"""
Implementation of stream filters for PDF.
"""
__author__ = "Mathieu Fenniak"
__author_email__ = "biziqe@mathieu.fenniak.net"

from .utils import PdfReadError, ord_, chr_
from sys import version_info
if version_info < ( 3, 0 ):
    from cStringIO import StringIO
else:
    from io import StringIO

try:
    import zlib

    def decompress(data):
        return zlib.decompress(data)

    def compress(data):
        return zlib.compress(data)

except ImportError:
    # Unable to import zlib.  Attempt to use the System.IO.Compression
    # library from the .NET framework. (IronPython only)
    import System
    from System import IO, Collections, Array

    def _string_to_bytearr(buf):
        retval = Array.CreateInstance(System.Byte, len(buf))
        for i in range(len(buf)):
            retval[i] = ord(buf[i])
        return retval

    def _bytearr_to_string(bytes):
        retval = ""
        for i in range(bytes.Length):
            retval += chr(bytes[i])
        return retval

    def _read_bytes(stream):
        ms = IO.MemoryStream()
        buf = Array.CreateInstance(System.Byte, 2048)
        while True:
            bytes = stream.Read(buf, 0, buf.Length)
            if bytes == 0:
                break
            else:
                ms.Write(buf, 0, bytes)
        retval = ms.ToArray()
        ms.Close()
        return retval

    def decompress(data):
        bytes = _string_to_bytearr(data)
        ms = IO.MemoryStream()
        ms.Write(bytes, 0, bytes.Length)
        ms.Position = 0  # fseek 0
        gz = IO.Compression.DeflateStream(ms, IO.Compression.CompressionMode.Decompress)
        bytes = _read_bytes(gz)
        retval = _bytearr_to_string(bytes)
        gz.Close()
        return retval

    def compress(data):
        bytes = _string_to_bytearr(data)
        ms = IO.MemoryStream()
        gz = IO.Compression.DeflateStream(ms, IO.Compression.CompressionMode.Compress, True)
        gz.Write(bytes, 0, bytes.Length)
        gz.Close()
        ms.Position = 0 # fseek 0
        bytes = ms.ToArray()
        retval = _bytearr_to_string(bytes)
        ms.Close()
        return retval


class FlateDecode(object):
    def decode(data, decodeParms):
        data = decompress(data)
        predictor = 1
        if decodeParms:
            try:
                predictor = decodeParms.get("/Predictor", 1)
            except AttributeError:
                pass    # usually an array with a null object was read

        # predictor 1 == no predictor
        if predictor != 1:
            columns = decodeParms["/Columns"]
            # PNG prediction:
            if predictor >= 10 and predictor <= 15:
                output = StringIO()
                # PNG prediction can vary from row to row
                rowlength = columns + 1
                assert len(data) % rowlength == 0
                prev_rowdata = (0,) * rowlength
                for row in range(len(data) // rowlength):
                    rowdata = [ord_(x) for x in data[(row*rowlength):((row+1)*rowlength)]]
                    filterByte = rowdata[0]
                    if filterByte == 0:
                        pass
                    elif filterByte == 1:
                        for i in range(2, rowlength):
                            rowdata[i] = (rowdata[i] + rowdata[i-1]) % 256
                    elif filterByte == 2:
                        for i in range(1, rowlength):
                            rowdata[i] = (rowdata[i] + prev_rowdata[i]) % 256
                    else:
                        # unsupported PNG filter
                        raise PdfReadError("Unsupported PNG filter %r" % filterByte)
                    prev_rowdata = rowdata
                    output.write(''.join([chr(x) for x in rowdata[1:]]))
                data = output.getvalue()
            else:
                # unsupported predictor
                raise PdfReadError("Unsupported flatedecode predictor %r" % predictor)
        return data
    decode = staticmethod(decode)

    def encode(data):
        return compress(data)
    encode = staticmethod(encode)


class ASCIIHexDecode(object):
    def decode(data, decodeParms=None):
        retval = ""
        char = ""
        x = 0
        while True:
            c = data[x]
            if c == ">":
                break
            elif c.isspace():
                x += 1
                continue
            char += c
            if len(char) == 2:
                retval += chr(int(char, base=16))
                char = ""
            x += 1
        assert char == ""
        return retval
    decode = staticmethod(decode)


class LZWDecode(object):
    """Taken from:
    http://www.java2s.com/Open-Source/Java-Document/PDF/PDF-Renderer/com/sun/pdfview/decode/LZWDecode.java.htm
    """
    class decoder(object):
        def __init__(self, data):
            self.STOP=257
            self.CLEARDICT=256
            self.data=data
            self.bytepos=0
            self.bitpos=0
            self.dict=[""]*4096
            for i in range(256):
                self.dict[i]=chr(i)
            self.resetDict()

        def resetDict(self):
            self.dictlen=258
            self.bitspercode=9

        def nextCode(self):
            fillbits=self.bitspercode
            value=0
            while fillbits>0 :
                if self.bytepos >= len(self.data):
                    return -1
                nextbits=ord(self.data[self.bytepos])
                bitsfromhere=8-self.bitpos
                if bitsfromhere>fillbits:
                    bitsfromhere=fillbits
                value |= (((nextbits >> (8-self.bitpos-bitsfromhere)) &
                           (0xff >> (8-bitsfromhere))) <<
                          (fillbits-bitsfromhere))
                fillbits -= bitsfromhere
                self.bitpos += bitsfromhere
                if self.bitpos >=8:
                    self.bitpos=0
                    self.bytepos = self.bytepos+1
            return value

        def decode(self):
            """ algorithm derived from:
            http://www.rasip.fer.hr/research/compress/algorithms/fund/lz/lzw.html
            and the PDFReference
            """
            cW = self.CLEARDICT;
            baos=""
            while True:
                pW = cW;
                cW = self.nextCode();
                if cW == -1:
                    raise PdfReadError("Missed the stop code in LZWDecode!")
                if cW == self.STOP:
                    break;
                elif cW == self.CLEARDICT:
                    self.resetDict();
                elif pW == self.CLEARDICT:
                    baos+=self.dict[cW]
                else:
                    if cW < self.dictlen:
                        baos += self.dict[cW]
                        p=self.dict[pW]+self.dict[cW][0]
                        self.dict[self.dictlen]=p
                        self.dictlen+=1
                    else:
                        p=self.dict[pW]+self.dict[pW][0]
                        baos+=p
                        self.dict[self.dictlen] = p;
                        self.dictlen+=1
                    if (self.dictlen >= (1 << self.bitspercode) - 1 and
                        self.bitspercode < 12):
                        self.bitspercode+=1
            return baos

    @staticmethod
    def decode(data,decodeParams=None):
        return LZWDecode.decoder(data).decode()


class ASCII85Decode(object):
    def decode(data, decodeParms=None):
        retval = ""
        group = []
        x = 0
        hitEod = False
        # remove all whitespace from data
        data = [y for y in data if not (y in ' \n\r\t')]
        while not hitEod:
            c = data[x]
            if len(retval) == 0 and c == "<" and data[x+1] == "~":
                x += 2
                continue
            #elif c.isspace():
            #    x += 1
            #    continue
            elif c == 'z':
                assert len(group) == 0
                retval += '\x00\x00\x00\x00'
                x += 1
                continue
            elif c == "~" and data[x+1] == ">":
                if len(group) != 0:
                    # cannot have a final group of just 1 char
                    assert len(group) > 1
                    cnt = len(group) - 1
                    group += [ 85, 85, 85 ]
                    hitEod = cnt
                else:
                    break
            else:
                c = ord(c) - 33
                assert c >= 0 and c < 85
                group += [ c ]
            if len(group) >= 5:
                b = group[0] * (85**4) + \
                    group[1] * (85**3) + \
                    group[2] * (85**2) + \
                    group[3] * 85 + \
                    group[4]
                assert b < (2**32 - 1)
                c4 = chr((b >> 0) % 256)
                c3 = chr((b >> 8) % 256)
                c2 = chr((b >> 16) % 256)
                c1 = chr(b >> 24)
                retval += (c1 + c2 + c3 + c4)
                if hitEod:
                    retval = retval[:-4+hitEod]
                group = []
            x += 1
        return retval
    decode = staticmethod(decode)


def decodeStreamData(stream):
    from .generic import NameObject
    filters = stream.get("/Filter", ())
    if len(filters) and not isinstance(filters[0], NameObject):
        # we have a single filter instance
        filters = (filters,)
    data = stream._data
    for filterType in filters:
        if filterType == "/FlateDecode":
            data = FlateDecode.decode(data, stream.get("/DecodeParms"))
        elif filterType == "/ASCIIHexDecode":
            data = ASCIIHexDecode.decode(data)
        elif filterType == "/LZWDecode":
            data = LZWDecode.decode(data, stream.get("/DecodeParms"))
        elif filterType == "/ASCII85Decode":
            data = ASCII85Decode.decode(data)
        elif filterType == "/Crypt":
            decodeParams = stream.get("/DecodeParams", {})
            if "/Name" not in decodeParams and "/Type" not in decodeParams:
                pass
            else:
                raise NotImplementedError("/Crypt filter with /Name or /Type not supported yet")
        else:
            # unsupported filter
            raise NotImplementedError("unsupported filter %s" % filterType)
    return data
